# ARCHS4

Queries gene-specific information from the [ARCHS4](https://maayanlab.cloud/archs4)
database.

This tool currently has two submodules.

| Module | Description |
|--------|-------------|
|[`correlate`](./archs4/correlate.md)| Performs a gene-correlation analysis |
|[`tissue`](./archs4/tissue.md)| Performs a tissue-enrichment analysis |
